@@ -1,12 +1,13 @@
-from PyObjCTools.TestSupport import *
-
 import libdispatch
+import objc
+from PyObjCTools.TestSupport import TestCase, min_os_level
 
-class TestTime (TestCase):
+
+class TestTime(TestCase):
     def test_constants(self):
-        self.assertEqual(libdispatch.NSEC_PER_SEC, 1000000000)
-        self.assertEqual(libdispatch.NSEC_PER_MSEC, 1000000)
-        self.assertEqual(libdispatch.USEC_PER_SEC, 1000000)
+        self.assertEqual(libdispatch.NSEC_PER_SEC, 1_000_000_000)
+        self.assertEqual(libdispatch.NSEC_PER_MSEC, 1_000_000)
+        self.assertEqual(libdispatch.USEC_PER_SEC, 1_000_000)
         self.assertEqual(libdispatch.NSEC_PER_USEC, 1000)
 
         self.assertEqual(libdispatch.DISPATCH_TIME_NOW, 0)
@@ -22,16 +23,12 @@ class TestTime (TestCase):
         self.assertEqual(tv.tv_sec, 0)
         self.assertEqual(tv.tv_nsec, 0)
 
-    @min_os_level('10.6')
+    @min_os_level("10.6")
     def test_functions(self):
         self.assertResultHasType(libdispatch.dispatch_time, objc._C_ULNGLNG)
         self.assertArgHasType(libdispatch.dispatch_time, 0, objc._C_ULNGLNG)
         self.assertArgHasType(libdispatch.dispatch_time, 1, objc._C_LNGLNG)
 
         self.assertResultHasType(libdispatch.dispatch_walltime, objc._C_ULNGLNG)
-        self.assertArgHasType(libdispatch.dispatch_walltime, 0, b'n^{timespec=ll}')
+        self.assertArgHasType(libdispatch.dispatch_walltime, 0, b"n^{timespec=ll}")
         self.assertArgHasType(libdispatch.dispatch_walltime, 1, objc._C_LNGLNG)
-
-
-if __name__ == "__main__":
-    main()
